@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Catalan_Thunderbird
    <ja>Thunderbird のカタロニア語版</ja>
    <kk>Catalan localisation of Thunderbird</kk>
    <ko>Catalan localisation of Thunderbird</ko>
+   <ku>Catalan localisation of Thunderbird</ku>
    <lt>Catalan localisation of Thunderbird</lt>
    <mk>Catalan localisation of Thunderbird</mk>
    <mr>Catalan localisation of Thunderbird</mr>
@@ -49,6 +50,7 @@ Catalan_Thunderbird
    <nb>Katalansk lokaltilpassing av Thunderbird</nb>
    <nl_BE>Catalan localisation of Thunderbird</nl_BE>
    <nl>Catalaanse lokalisatie van Thunderbird</nl>
+   <or>Catalan localisation of Thunderbird</or>
    <pl>Katalońska lokalizacja Thunderbirda</pl>
    <pt_BR>Catalão Localização para o Thunderbird</pt_BR>
    <pt>Catalão Localização para Thunderbird</pt>
@@ -56,6 +58,7 @@ Catalan_Thunderbird
    <ru>Catalan localisation of Thunderbird</ru>
    <sk>Catalan localisation of Thunderbird</sk>
    <sl>Katalonske krajevne nastavitve za Thunderbird</sl>
+   <so>Catalan localisation of Thunderbird</so>
    <sq>Përkthimi i Thunderbird-it në katalanisht</sq>
    <sr>Catalan localisation of Thunderbird</sr>
    <sv>Katalansk lokalisering av Thunderbird</sv>
