@@ -78,12 +78,11 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
-apt-get update
+
 </preinstall>
 
 <install_package_names>
--t bullseye-backports libreoffice-base-core
+-t bookworm-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -97,8 +96,7 @@ libreoffice-gtk3
 </install_package_names>
 
 <postinstall>
-rm /etc/apt/sources.list.d/pitemp.list
-apt-get update
+
 </postinstall>
 
 <uninstall_package_names>
