@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ Danish
    <ja>Hunspell 用デンマーク語辞書</ja>
    <kk>Danish dictionary for hunspell</kk>
    <ko>Danish dictionary for hunspell</ko>
+   <ku>Danish dictionary for hunspell</ku>
    <lt>Danish dictionary for hunspell</lt>
    <mk>Danish dictionary for hunspell</mk>
    <mr>Danish dictionary for hunspell</mr>
    <nb_NO>Danish dictionary for hunspell</nb_NO>
    <nb>Dansk ordliste for hunspell</nb>
    <nl_BE>Danish dictionary for hunspell</nl_BE>
-   <nl>Danish dictionary for hunspell</nl>
+   <nl>Deens woordenboek voor hunspell</nl>
+   <or>Danish dictionary for hunspell</or>
    <pl>Danish dictionary for hunspell</pl>
    <pt_BR>Dicionário Dinamarquês para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Dinamarquês para hunspell</pt>
@@ -56,6 +58,7 @@ Danish
    <ru>Danish dictionary for hunspell</ru>
    <sk>Danish dictionary for hunspell</sk>
    <sl>Danski slovar za hunspell</sl>
+   <so>Danish dictionary for hunspell</so>
    <sq>Fjalor danisht për hunspell</sq>
    <sr>Danish dictionary for hunspell</sr>
    <sv>Dansk ordbok för hunspell</sv>
