@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ GB_English_Firefox
    <ja>Firefox のイギリス英語版</ja>
    <kk>GB English localisation of Firefox</kk>
    <ko>GB English localisation of Firefox</ko>
+   <ku>GB English localisation of Firefox</ku>
    <lt>GB English localisation of Firefox</lt>
    <mk>GB English localisation of Firefox</mk>
    <mr>GB English localisation of Firefox</mr>
@@ -49,6 +50,7 @@ GB_English_Firefox
    <nb>Britisk engelsk lokaltilpassing av Firefox</nb>
    <nl_BE>GB English localisation of Firefox</nl_BE>
    <nl>GB Engelse lokalisatie van Firefox</nl>
+   <or>GB English localisation of Firefox</or>
    <pl>Angielski Brytyjski lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Inglês da Grã-Bretanha Localização para o Firefox</pt_BR>
    <pt>Inglês GB Localização para Firefox</pt>
@@ -56,6 +58,7 @@ GB_English_Firefox
    <ru>GB English localisation of Firefox</ru>
    <sk>GB English localisation of Firefox</sk>
    <sl>VB angleške krajevne nastavitve za Firefox</sl>
+   <so>GB English localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në anglishte britanike</sq>
    <sr>GB English localisation of Firefox</sr>
    <sv>GB Engelsk lokalisering av Firefox</sv>
