@@ -78,17 +78,15 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
-apt-get update
+
 </preinstall>
 
 <install_package_names>
--t bullseye-backports libreoffice-help-en-us
+-t bookworm-backports libreoffice-help-en-us
 </install_package_names>
 
 <postinstall>
-rm /etc/apt/sources.list.d/pitemp.list
-apt-get update
+
 </postinstall>
 
 <uninstall_package_names>
