@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Estonian_Firefox
    <ja>Firefox のエストニア語版</ja>
    <kk>Estonian localisation of Firefox</kk>
    <ko>Estonian localisation of Firefox</ko>
+   <ku>Estonian localisation of Firefox</ku>
    <lt>Estonian localisation of Firefox</lt>
    <mk>Estonian localisation of Firefox</mk>
    <mr>Estonian localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Estonian_Firefox
    <nb>Estisk lokaltilpassing av Firefox</nb>
    <nl_BE>Estonian localisation of Firefox</nl_BE>
    <nl>Estische lokalisatie van Firefox</nl>
+   <or>Estonian localisation of Firefox</or>
    <pl>Estońska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Estónio Localização para o Firefox</pt_BR>
    <pt>Estónio Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Estonian_Firefox
    <ru>Estonian localisation of Firefox</ru>
    <sk>Estonian localisation of Firefox</sk>
    <sl>Estonska lokalizacija za Firefox</sl>
+   <so>Estonian localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në estonisht</sq>
    <sr>Estonian localisation of Firefox</sr>
    <sv>Estnisk lokalisering av Firefox</sv>
