@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Italian_Firefox
    <ja>Firefox のイタリア語版</ja>
    <kk>Italian localisation of Firefox</kk>
    <ko>Italian localisation of Firefox</ko>
+   <ku>Italian localisation of Firefox</ku>
    <lt>Italian localisation of Firefox</lt>
    <mk>Italian localisation of Firefox</mk>
    <mr>Italian localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Italian_Firefox
    <nb>Italiensk lokaltilpassing av Firefox</nb>
    <nl_BE>Italian localisation of Firefox</nl_BE>
    <nl>Italiaanse lokalisatie van Firefox</nl>
+   <or>Italian localisation of Firefox</or>
    <pl>Włoska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Italiano Localização para o Firefox</pt_BR>
    <pt>Italiano Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Italian_Firefox
    <ru>Итальянская локализация Firefox</ru>
    <sk>Italian localisation of Firefox</sk>
    <sl>Italijanske krajevne nastavitve za Firefox</sl>
+   <so>Italian localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në italisht</sq>
    <sr>Italian localisation of Firefox</sr>
    <sv>Italiensk lokalisering av Firefox </sv>
