@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Korean_Firefox
    <ja>Firefox の韓国（朝鮮）語版</ja>
    <kk>Korean localisation of Firefox</kk>
    <ko>Korean localisation of Firefox</ko>
+   <ku>Korean localisation of Firefox</ku>
    <lt>Korean localisation of Firefox</lt>
    <mk>Korean localisation of Firefox</mk>
    <mr>Korean localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Korean_Firefox
    <nb>Koreansk lokaltilpassing av Firefox</nb>
    <nl_BE>Korean localisation of Firefox</nl_BE>
    <nl>Koreaanse lokalisatie van Firefox</nl>
+   <or>Korean localisation of Firefox</or>
    <pl>Koreańska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Coreano Localização para o Firefox</pt_BR>
    <pt>Coreano Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Korean_Firefox
    <ru>Корейская локализация Firefox</ru>
    <sk>Korean localisation of Firefox</sk>
    <sl>Korejske krajevne nastavitve za Firefox</sl>
+   <so>Korean localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në koreançe</sq>
    <sr>Korean localisation of Firefox</sr>
    <sv>Koreansk lokalisering av Firefox</sv>
