@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Latvian
    <ja>Hunspell 用ラトビア語辞書</ja>
    <kk>Latvian dictionary for hunspell</kk>
    <ko>Latvian dictionary for hunspell</ko>
+   <ku>Latvian dictionary for hunspell</ku>
    <lt>Latvian dictionary for hunspell</lt>
    <mk>Latvian dictionary for hunspell</mk>
    <mr>Latvian dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Latvian
    <nb>Latvisk ordliste for hunspell</nb>
    <nl_BE>Latvian dictionary for hunspell</nl_BE>
    <nl>Latvian dictionary for hunspell</nl>
+   <or>Latvian dictionary for hunspell</or>
    <pl>Latvian dictionary for hunspell</pl>
    <pt_BR>Dicionário Letão para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Letão para hunspell</pt>
@@ -56,6 +58,7 @@ Latvian
    <ru>Latvian dictionary for hunspell</ru>
    <sk>Latvian dictionary for hunspell</sk>
    <sl>Latvijski slovar za hunspell</sl>
+   <so>Latvian dictionary for hunspell</so>
    <sq>Fjalor letonisht për hunspell</sq>
    <sr>Latvian dictionary for hunspell</sr>
    <sv>Lettisk ordbok för hunspell</sv>
