@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Russian
    <ja>Hunspell 用ロシア語辞書</ja>
    <kk>Russian dictionary for hunspell</kk>
    <ko>Russian dictionary for hunspell</ko>
+   <ku>Russian dictionary for hunspell</ku>
    <lt>Russian dictionary for hunspell</lt>
    <mk>Russian dictionary for hunspell</mk>
    <mr>Russian dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Russian
    <nb>Russisk ordliste for hunspell</nb>
    <nl_BE>Russian dictionary for hunspell</nl_BE>
    <nl>Russian dictionary for hunspell</nl>
+   <or>Russian dictionary for hunspell</or>
    <pl>Russian dictionary for hunspell</pl>
    <pt_BR>Dicionário Russo para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Russo para hunspell</pt>
@@ -56,6 +58,7 @@ Russian
    <ru>Russian dictionary for hunspell</ru>
    <sk>Russian dictionary for hunspell</sk>
    <sl>Ruski slovar za hunspell</sl>
+   <so>Russian dictionary for hunspell</so>
    <sq>Fjalor rusisht për hunspell</sq>
    <sr>Russian dictionary for hunspell</sr>
    <sv>Rysk ordbok för hunspell</sv>
