@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Serbian_Default_Firefox_esr
    <ja>セルビア語版 Firefox ESR</ja>
    <kk>Serbian localisation of Firefox ESR</kk>
    <ko>Serbian localisation of Firefox ESR</ko>
+   <ku>Serbian localisation of Firefox ESR</ku>
    <lt>Serbian localisation of Firefox ESR</lt>
    <mk>Serbian localisation of Firefox ESR</mk>
    <mr>Serbian localisation of Firefox ESR</mr>
@@ -49,6 +50,7 @@ Serbian_Default_Firefox_esr
    <nb>Serbisk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Serbian localisation of Firefox ESR</nl_BE>
    <nl>Serbian localisation of Firefox ESR</nl>
+   <or>Serbian localisation of Firefox ESR</or>
    <pl>Serbian localisation of Firefox ESR</pl>
    <pt_BR>Sérvio Localização para o Firefox ESR</pt_BR>
    <pt>Sérvio Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Serbian_Default_Firefox_esr
    <ru>Serbian localisation of Firefox ESR</ru>
    <sk>Serbian localisation of Firefox ESR</sk>
    <sl>Srbske krajevne nastavitve za Firefox ESR</sl>
+   <so>Serbian localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në serbisht</sq>
    <sr>Serbian localisation of Firefox ESR</sr>
    <sv>Serbisk lokalisering av Firefox ESR</sv>
