@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Slovenian_Default_Firefox_esr
    <ja>スロベニア語版 Firefox ESR</ja>
    <kk>Slovenian localisation of Firefox ESR</kk>
    <ko>Slovenian localisation of Firefox ESR</ko>
+   <ku>Slovenian localisation of Firefox ESR</ku>
    <lt>Slovenian localisation of Firefox ESR</lt>
    <mk>Slovenian localisation of Firefox ESR</mk>
    <mr>Slovenian localisation of Firefox ESR</mr>
@@ -49,6 +50,7 @@ Slovenian_Default_Firefox_esr
    <nb>Slovensk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Slovenian localisation of Firefox ESR</nl_BE>
    <nl>Slovenian localisation of Firefox ESR</nl>
+   <or>Slovenian localisation of Firefox ESR</or>
    <pl>Slovenian localisation of Firefox ESR</pl>
    <pt_BR>Esloveno Localização para o Firefox ESR</pt_BR>
    <pt>Esloveno Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Slovenian_Default_Firefox_esr
    <ru>Slovenian localisation of Firefox ESR</ru>
    <sk>Slovenian localisation of Firefox ESR</sk>
    <sl>Slovenske krajevne nastavitve za Firefox ESR</sl>
+   <so>Slovenian localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në sllovenisht</sq>
    <sr>Slovenian localisation of Firefox ESR</sr>
    <sv>Slovensk lokalisering av Firefox ESR</sv>
