@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ CUPS
    <ja>CUPS 印刷システム</ja>
    <kk>CUPS Printing system</kk>
    <ko>CUPS Printing system</ko>
+   <ku>CUPS Printing system</ku>
    <lt>CUPS Printing system</lt>
    <mk>CUPS Printing system</mk>
    <mr>CUPS Printing system</mr>
    <nb_NO>CUPS Printing system</nb_NO>
    <nb>CUPS utskriftssystem</nb>
    <nl_BE>CUPS Printing system</nl_BE>
-   <nl>CUPS Printing system</nl>
+   <nl>CUPS-afdruksysteem</nl>
+   <or>CUPS Printing system</or>
    <pl>CUPS Printing system</pl>
    <pt_BR>Sistema de Impressão CUPS</pt_BR>
    <pt>Sistema de impressão CUPS (Common Unix Printing System)</pt>
@@ -56,6 +58,7 @@ CUPS
    <ru>CUPS Printing system</ru>
    <sk>CUPS Printing system</sk>
    <sl>CUPS sistem za tiskanje</sl>
+   <so>CUPS Printing system</so>
    <sq>Sistemi CUPS për shtypje</sq>
    <sr>CUPS Printing system</sr>
    <sv>CUPS Skrivarsystem</sv>
