@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Filezilla
    <ja>使いやすい GUI を備えたフル機能の FTP クライアント</ja>
    <kk>a full-featured FTP client with an easy-to-use GUI</kk>
    <ko>a full-featured FTP client with an easy-to-use GUI</ko>
+   <ku>a full-featured FTP client with an easy-to-use GUI</ku>
    <lt>a full-featured FTP client with an easy-to-use GUI</lt>
    <mk>a full-featured FTP client with an easy-to-use GUI</mk>
    <mr>a full-featured FTP client with an easy-to-use GUI</mr>
@@ -49,6 +50,7 @@ Filezilla
    <nb>FTP-klient med full funksjonalitet og grafisk brukergrensesnitt</nb>
    <nl_BE>a full-featured FTP client with an easy-to-use GUI</nl_BE>
    <nl>een volledig voorzien FTP programma met een makkelijk te gebruiken grafische werkomgeving</nl>
+   <or>a full-featured FTP client with an easy-to-use GUI</or>
    <pl>w pełni funkcjonalny klient FTP z łatwym w użyciu interfejsem graficznym</pl>
    <pt_BR>Cliente FTP completo com interface gráfica intuitiva</pt_BR>
    <pt>Cliente FTP completo com interface gráfica intuitiva</pt>
@@ -56,6 +58,7 @@ Filezilla
    <ru>Полнофункциональный FTP клиент с удобным GUI</ru>
    <sk>a full-featured FTP client with an easy-to-use GUI</sk>
    <sl>Polnozmogljiv FTP odjemalec z enostavnim uporabniškim vmesnikom</sl>
+   <so>a full-featured FTP client with an easy-to-use GUI</so>
    <sq>Një klient FTP i plotë për nga veçoritë, me një GUI të lehtë për t’u përdorur</sq>
    <sr>a full-featured FTP client with an easy-to-use GUI</sr>
    <sv>en fullutrustad FTP klient med lättanvänt grafiskt gränssnitt</sv>
