@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ fvwm_crystal
    <ja>FVWM-Crystal ウィンドウマネージャ</ja>
    <kk>fvwm-crystal window manager</kk>
    <ko>fvwm-crystal window manager</ko>
+   <ku>fvwm-crystal window manager</ku>
    <lt>fvwm-crystal window manager</lt>
    <mk>fvwm-crystal window manager</mk>
    <mr>fvwm-crystal window manager</mr>
    <nb_NO>fvwm-crystal window manager</nb_NO>
    <nb>Vindusbehandleren fvwm-crystal</nb>
    <nl_BE>fvwm-crystal window manager</nl_BE>
-   <nl>fvwm-crystal window manager</nl>
+   <nl>fvwm-crystal venster beheerder</nl>
+   <or>fvwm-crystal window manager</or>
    <pl>fvwm-crystal window manager</pl>
    <pt_BR>fvwm-crystal gerenciador de janelas</pt_BR>
    <pt>Gestor de janelas fvwm-crystal</pt>
@@ -56,6 +58,7 @@ fvwm_crystal
    <ru>fvwm-crystal window manager</ru>
    <sk>fvwm-crystal window manager</sk>
    <sl>fvwm-crystal okenski upravljalnik</sl>
+   <so>fvwm-crystal window manager</so>
    <sq>Përgjegjësi fvwm-crystal i dritareve</sq>
    <sr>fvwm-crystal window manager</sr>
    <sv>fvwm-crystal fönsterhanterare</sv>
