@@ -2,7 +2,7 @@
 <app>
 
 <category>
-Desktop Environment
+Desktop Environments
 </category>
 
 <name>
