@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ PCManFM
    <ja>高速で軽量なファイルマネージャ</ja>
    <kk>a fast and lightweight file manager</kk>
    <ko>a fast and lightweight file manager</ko>
+   <ku>a fast and lightweight file manager</ku>
    <lt>greita ir supaprastinta failų tvarkytuvė</lt>
    <mk>a fast and lightweight file manager</mk>
    <mr>a fast and lightweight file manager</mr>
@@ -49,6 +50,7 @@ PCManFM
    <nb>rask og lettvektig filbehandler</nb>
    <nl_BE>a fast and lightweight file manager</nl_BE>
    <nl>een snelle en lichtgewicht bestandsmanager</nl>
+   <or>a fast and lightweight file manager</or>
    <pl>szybki i lekki menedżer plików</pl>
    <pt_BR>Gerenciador de arquivos rápido e leve</pt_BR>
    <pt>Gestor de ficheiros ligeiro e rápido</pt>
@@ -56,6 +58,7 @@ PCManFM
    <ru>Быстрый и легковесный файловый менеджер</ru>
    <sk>a fast and lightweight file manager</sk>
    <sl>Lahek in hiter upravljalnik datotek</sl>
+   <so>a fast and lightweight file manager</so>
    <sq>Një përgjegjës kartelash i shpejtë dhe i peshës së lehtë</sq>
    <sr>a fast and lightweight file manager</sr>
    <sv>en snabb lättvikts filhanterare</sv>
