@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 
@@ -83,7 +83,6 @@ all
 </preinstall>
 
 <install_package_names>
-gtk-recordmydesktop
 recordmydesktop
 </install_package_names>
 
@@ -94,7 +93,6 @@ recordmydesktop
 
 
 <uninstall_package_names>
-gtk-recordmydesktop
 recordmydesktop
 </uninstall_package_names>
 
