@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -27,7 +27,7 @@ tint2
    <eu>Simple panel/taskbar</eu>
    <fa>Simple panel/taskbar</fa>
    <fil_PH>Simple panel/taskbar</fil_PH>
-   <fi>Yksinkertainen paneeli/tehtäväpalkki</fi>
+   <fi>Simple panel/taskbar</fi>
    <fr_BE>Panneau ou barre de tâches simple</fr_BE>
    <fr>Panneau ou barre de tâches simple</fr>
    <gl_ES>Simple panel/taskbar</gl_ES>
@@ -42,6 +42,7 @@ tint2
    <ja>Simple panel/taskbar</ja>
    <kk>Simple panel/taskbar</kk>
    <ko>Simple panel/taskbar</ko>
+   <ku>Simple panel/taskbar</ku>
    <lt>Simple panel/taskbar</lt>
    <mk>Simple panel/taskbar</mk>
    <mr>Simple panel/taskbar</mr>
@@ -49,13 +50,15 @@ tint2
    <nb>Enkelt programpanel</nb>
    <nl_BE>Simple panel/taskbar</nl_BE>
    <nl>Simple panel/taskbar</nl>
+   <or>Simple panel/taskbar</or>
    <pl>Simple panel/taskbar</pl>
    <pt_BR>Painel ou barra de tarefas simples</pt_BR>
    <pt>Painel/barra de tarefas simples</pt>
    <ro>Simple panel/taskbar</ro>
    <ru>Simple panel/taskbar</ru>
    <sk>Simple panel/taskbar</sk>
-   <sl>Simple panel/taskbar</sl>
+   <sl>Preprost pano/opravilna vrstica</sl>
+   <so>Simple panel/taskbar</so>
    <sq>Panel/shtyllë aktesh i thjeshtë</sq>
    <sr>Simple panel/taskbar</sr>
    <sv>Enkelt panel/aktivitetsfält</sv>
